function getBrandNameFromURL() {
  const urlParams = new URLSearchParams(window.location.search);
  const redirectUri = urlParams.get("redirect_uri");
  const state = urlParams.get("state");

  let brandId;
  brandId = new URLSearchParams(new URL(new URLSearchParams(window.location.search).get("redirect_uri")).search).get("brand");
  const serviceRx = /(?<=\/eoxhub-gateway\/)(.*)(?=\/user-area)/;
  const dashboardRx = /(?<=dashboard.)(.+?)(?=\.)/;
  const deepEsdlRx = /(?<=deep.)(earthsystemdatalab)(?=\.)/;
  if (typeof brandId === "undefined") {
    // fallback to previous check for now if no brand id present
    if (redirectUri) {
      brandId = serviceRx.exec(redirectUri)?.[1]
      || dashboardRx.exec(redirectUri)?.[1]
      || deepEsdlRx.exec(redirectUri)?.[1];
    }
    if (state && !brandId) {
      brandId = serviceRx.exec(state)?.[1]
      || dashboardRx.exec(state)?.[1]
      || deepEsdlRx.exec(redirectUri)?.[1];
    }
  }
  
  return brandId || "eoxhub";
}

function applyBrandConfig(config) {
  document.body.style.setProperty("--primary", config.theme.primary_color)
  const headerLogo = document.querySelector(".kc-logo");

  if (headerLogo) {
    headerLogo.src = config.logo;
  }

  const logoLink = document.querySelector("#kc-logo-link");
  if (config.userArea && config.userArea.root && logoLink) {
    logoLink.href = config.userArea.root;
  }

  // const tosPrivacy = document.querySelector(".tosPrivacy");
  // if (tosPrivacy && config.legal && config.legal.description) {
  //   tosPrivacy.innerHTML = config.legal.description;
  // }

  const links = document.querySelectorAll("h4 > a");
  links.forEach((link) => {
    link.style.color = `${config.theme.primary_color}`;
  });

  const pageTitle = document.querySelector("#kc-page-title > strong");
  if (pageTitle && config.meta && config.meta.title) {
    pageTitle.textContent = `${config.meta.title}!`;
  }

  // const loginCard = document.querySelector(".card-pf");
  // if (loginCard) {
  //   loginCard.style.borderColor = config.theme.primary_color;
  // }

  const contactLink = document.querySelector("#contactLink");
  if (contactLink) {
    if (config.contact && config.contact.email) {
      contactLink.href = `mailto: ${config.contact.email}`;
    }
    contactLink.style.color = `${config.theme.primary_color}`;
  }

  // add redirect_uri to forgot password and register links such
  // that dynamic branding can be applied to them as well
  const forgotPasswordDiv = document.querySelector("#forgotPassword");

  if (forgotPasswordDiv) {
    const anchor = forgotPasswordDiv.querySelector("a");
    if (anchor) {
      const urlParams = new URLSearchParams(window.location.search);
      const redirectUri = urlParams.get("redirect_uri");
      if (redirectUri) {
        anchor.href = `${anchor.href}&redirect_uri=${redirectUri}`
      }
    }
  }
  const registerDiv = document.querySelector("#kc-registration");
  if (registerDiv) {
    const anchor = registerDiv.querySelector("p > a");
    if (anchor) {
      const urlParams = new URLSearchParams(window.location.search);
      const redirectUri = urlParams.get("redirect_uri");
      if (redirectUri) {
        anchor.href = `${anchor.href}&redirect_uri=${redirectUri}`
      }
    }
  }

  const backToLogin = document.querySelector("#backToLogin");
  if (backToLogin) {
    const urlParams = new URLSearchParams(window.location.search);
    const redirectUri = urlParams.get("redirect_uri");
    console.log(urlParams, redirectUri)
    if (redirectUri) {
      backToLogin.href = `${backToLogin.href}&redirect_uri=${redirectUri}`
      console.log(backToLogin)
    }
  }

  document.body.style.opacity = "1";
}

function loadBrandConfig() {
  const brandName = getBrandNameFromURL();
  const importPath = `https://hub-brands.eox.at/${brandName}/config.mjs`;

  import(importPath)
    .then(({ config }) => {
      globalThis.brandConfig = config;

      if (document.readyState === "loading") {
        document.addEventListener("DOMContentLoaded", () =>
          applyBrandConfig(config)
        );
      } else {
        applyBrandConfig(config);
      }
    })
    .catch((e) => {
      console.log(`Import from ${importPath} failed`);
      console.error(e);
    });
}

loadBrandConfig();
